@@ -23,6 +23,7 @@ ACTIONS = (
     'clean',
     'time-upload',
     'time-download',
+    'time-sql',
 )
 MULTIPART_THREHOLD = 64 * 2**20
 MULTIPART_CHUNKSIZE = 8 * 2**20
@@ -296,6 +297,29 @@ class Controller:
         stats = benchmark.make_stats()
         self.print_stats(stats)
 
+    def time_sql(self):
+        DEFAULT_EXPRESSION = 'SELECT COUNT(*)'
+        self.subparser.add_argument('--storage-class', required=False)
+        self.subparser.add_argument('--rows', type=int, required=False)
+        self.subparser.add_argument('--columns', type=str, default='int', required=False)
+        self.subparser.add_argument('--randomseed', type=int, required=False)
+        self.subparser.add_argument('--expression', type=str, default=DEFAULT_EXPRESSION,
+                                    required=False)
+        parsed_args = self.parser.parse_known_args()[0]
+
+        benchmark = benchmarks.SqlBenchmark(self.driver)
+        benchmark.set_params(
+            storage_class=parsed_args.storage_class,
+            rows=parsed_args.rows,
+            columns=parsed_args.columns,
+            expression=parsed_args.expression,
+        )
+        benchmark.setup()
+        benchmark.run()
+        benchmark.tear_down()
+        stats = benchmark.make_stats()
+        self.print_stats(stats)
+
     def print_stats(self, stats):
         template = '%s\t\t%s'
         print(template % ('version', os_benchmark.__version__))
